profile ukfs_2x_tun_11a {

	Sample template for DynaTrax testing
	Copyright  Trainsimfiles.com

	header {
		#regid may be used for ensuring profiles are approved/registered
		regid=ukfs_1x.trainsimfiles.uk

		#profileSet is the track system the profile belongs to
		profileSet=UK FineScale

		#profileName is a description of the profile
		profilename=UK FineScale Standard Gauge 2x tunnel 11a

		#url/email for profile issues
		support=http://www.digital-rails.us

		#gauge value, only to be used later for selecting profiles by gauge instead of track set
		gauge=1.435
	}

	#note: all lengths/distances and point coordinates are in metres, angles are degrees, and 
	
	#segmentation parameters sets how segmentation of shapes is to occur
	#by setting a maximum segment angle, and minimum plus maximum segment lengths 
	#these allow the track to be segmented according to the track developers desired quality
	
	#the segment angle is used on curves to set the maximum segmentation angle
	#lower values = smoother curves = more polygons
	maxSegAngle=0.75

	#this avoids very sharp curves from using large numbers of polygons 
	minSegLength=1.0

	#maxSegLength sets the maximum polygon length a value <20m is recommended so when lit at night by headlamps 
	#the surface is evenly lit (avoids pulsating surfaces).
	maxSegLength=12.5

	#List of materials to be used for the shape
	#materials: name (filename,mip bias,shader,filter,lighting,alphamode,zbuffer,u_scale,v_scale)
	#u_scale and v_scale are in metres and are the physical distances the texture covers (ie. length / u_scale = u )
	#note: some parameters are based on GMAX materials form
	#eg. zbuffer=test, this makes shadows appear on that surface
	material=BALLAST (ukfs_track2.ace,0,TexDiff,LinearMipLinear,OptSpecular0,none,normal,0,6.096)
	material=TUNNEL (ukfs_tunnel.ace,0,TexDiff,LinearMipLinear,OptSpecular0,none,normal,6.096,0)
	material=RAILS (ukfs_rail.ace,0,TexDiff,LinearMipLinear,OptSpecular750,none,normal,5,0)
	material=RAILTOPS (ukfs_rail.ace,0,TexDiff,LinearMipLinear,OptSpecular25,none,normal,5,0)
	material=SLEEPERS (ukfs_sleepers.ace,0,BlendATexDiff,LinearMipLinear,OptSpecular0,none,normal,0,6.096)
	material=RAILCHAIRS (ukfs_track1.ace,-2,BlendATexDiff,LinearMipLinear,OptSpecular0,trans,normal,0,6.096)

	#List of unique points that describe the shape - this avoids having to repeat coordinates in profile lines later on
	points=(-4.7877,0.06,0)(-3.7877,0.11,0)(0,0.11,0)(3.7877,0.11,0)(4.7877,0.06,0)
	points=(4.786,0,0)(4.786,2,0)(4.59,3.236,0)(4.046,4.351,0)(3.137,5.236,0)(2.022,5.804,0)
	points=(0,6,0)
	points=(-2.022,5.804,0)(-3.137,5.236,0)(-4.046,4.351,0)(-4.59,3.236,0)(-4.786,2,0)(-4.786,0,0)
	points=(-3.285,0.15,0)(-3.285,0.3,0)(-3.21,0.3,0)(-3.21,0.15,0)
	points=(-1.775,0.15,0)(-1.775,0.3,0)(-1.7,0.3,0)(-1.7,0.15,0)
	points=(1.7,0.15,0)(1.7,0.3,0)(1.775,0.3,0)(1.775,0.15,0)
	points=(3.21,0.15,0)(3.21,0.3,0)(3.285,0.3,0)(3.285,0.15,0)
	points=(-3.7877,0.12,0)(-1.1973,0.12,0)
	points=(1.1973,0.12,0)(3.7877,0.12,0)
	points=(-3.375,0.11,0)(-3.285,0.2,0)(-3.21,0.2,0,0)(-3.12,0.11,0)
	points=(-1.865,0.11,0)(-1.775,0.2,0,0)(-1.7,0.2,0)(-1.61,0.11,0)
	points=(1.61,0.11,0)(1.7,0.2,0)(1.775,0.2,0,0)(1.865,0.11,0)
	points=(3.12,0.11,0)(3.21,0.2,0,0)(3.285,0.2,0)(3.375,0.11,0)

	#List of UV mapping points for tiling: 0,0 is bottom left of texture
	uvpoints=(0.246,0)(0.412,0)(0.898,0)(0.412,0)(0.246,0)
	uvpoints=(0,1)(0,0.758)(0,0.607)(0,0.456)(0,0.305)(0,0.153)
	uvpoints=(0,0.002)
	uvpoints=(0,0.153)(0,0.305)(0,0.456)(0,0.607)(0,0.758)(0,1)
	uvpoints=(0,0.562)(0,0.537)(0,0.516)(0,0.535)
	uvpoints=(0.412,0)(0.834,0)
	uvpoints=(0,0)(0.02,0)(0.040,0)

	#set number of LOD levels and distances
	#note: half shape length is added to first LOD distance automatically
	lods=50,400,2000
	
	#degrade values for each lod level; divides the number of segments to be generated by this value
	# a value of 1 leaves the segmentation as determined by segmentation values above
	degrade=1,2,4

	#'list of distinct objects, each object can have 1 material only - though objects can share materials
	#any number of objects may be added, though for performance reasons the fewer the better
	#multi-material objects not yet supported

	#'currently must be in order of LOD and subobject.

	object BASE {
		#subobject is used for alpha sorting purposes, though not really require for track
		#a value of 1 is used for UKFS shapes to force sleepers to overwrite the trackbed (avoids sleeper/ballast contention)
		subobject=0

		#the material use for this object, from the list above
		materialName=BALLAST

		#profile=lod level, (point number,uv number),( ... )
		#point and uv numbers are from the list above, starting at 0
		#all points on one profile line will be welded, for smooth continous surfaces
		#use a profile line to start a new surface
		profile=0,(0,0)(1,1)(2,2)(3,3)(4,4)
		profile=1,(0,0)(1,1)(2,2)(3,3)(4,4)
		profile=2,(0,0)(1,1)(2,2)(3,3)(4,4)
	}
	object RAILS {
		subobject=0
		materialName=RAILS
		profile=0,(18,18)(19,19)
		profile=0,(20,19)(21,18)
		profile=0,(22,18)(23,19)
		profile=0,(24,19)(25,18)
		profile=0,(26,18)(27,19)
		profile=0,(28,19)(29,18)
		profile=0,(30,18)(31,19)
		profile=0,(32,19)(33,18)
		profile=1,(18,18)(19,19)
		profile=1,(20,19)(21,18)
		profile=1,(22,18)(23,19)
		profile=1,(24,19)(25,18)
		profile=1,(26,18)(27,19)
		profile=1,(28,19)(29,18)
		profile=1,(30,18)(31,19)
		profile=1,(32,19)(33,18)
	}
	object RAILTOPS {
		subobject=0
		materialName=RAILTOPS
		profile=0,(19,20)(20,21)
		profile=0,(23,20)(24,21)
		profile=0,(27,20)(28,21)
		profile=0,(31,20)(32,21)
		profile=1,(19,20)(20,21)
		profile=1,(23,20)(24,21)
		profile=1,(27,20)(28,21)
		profile=1,(31,20)(32,21)
	}
	object TUNNEL {
		subobject=0
		materialName=TUNNEL
		profile=0,(5,5)(6,6)(7,7)(8,8)(9,9)(10,10)(11,11)(12,12)(13,13)(14,14)(15,15)(16,16)(17,17)
		profile=1,(5,5)(6,6)(7,7)(8,8)(9,9)(10,10)(11,11)(12,12)(13,13)(14,14)(15,15)(16,16)(17,17)
		profile=2,(5,5)(6,6)(7,7)(8,8)(9,9)(10,10)(11,11)(12,12)(13,13)(14,14)(15,15)(16,16)(17,17)
	}
	object SLEEPERS {
		subobject=0
		materialName=SLEEPERS
		profile=0,(34,22)(35,23)
		profile=0,(36,23)(37,22)
		profile=1,(34,22)(35,23)
		profile=1,(36,23)(37,22)
		profile=2,(34,22)(35,23)
		profile=2,(36,23)(37,22)
	}
	object RAILCHAIRS {
		subobject=0
		materialName=RAILCHAIRS
		profile=0,(38,24)(39,25)
		profile=0,(40,25)(41,26)
		profile=0,(42,26)(43,25)
		profile=0,(44,25)(45,24)
		profile=0,(46,24)(47,25)
		profile=0,(48,25)(49,26)
		profile=0,(50,26)(51,25)
		profile=0,(52,25)(53,24)
	}
}